import { Component, OnInit } from '@angular/core';
import {ValidatorsService} from '../../../services/validators.service';
import {SalesmanService} from '../../../services/salesman.service';
import {UntypedFormBuilder, UntypedFormGroup, Validators} from '@angular/forms';
import {NzModalService} from 'ng-zorro-antd';
import {ActivatedRoute, Router} from '@angular/router';

@Component({
  selector: 'app-salesman-add',
  templateUrl: './salesman-add.component.html',
  styleUrls: ['./salesman-add.component.scss']
})
export class SalesmanAddComponent implements OnInit {

  salesmanForm: UntypedFormGroup;
  btnLoading = false;

  constructor(private form: UntypedFormBuilder,
              private modal: NzModalService,
              private salesmanService: SalesmanService,
              private activatedRoute: ActivatedRoute,
              private router: Router) { }

  ngOnInit(): void {
    this.salesmanForm = this.form.group({
      loginName: [null, [Validators.required, ValidatorsService.minLength(6), ValidatorsService.maxLength(20)]],
      password: [null, [Validators.required, ValidatorsService.minLength(6), ValidatorsService.maxLength(20)]],
      name: [null, [Validators.required]],
      phone: [null, [Validators.required]],
    });
  }

  submitFrom() {
    this.btnLoading = true;
    for (const i in this.salesmanForm.controls) {
      this.salesmanForm.controls[i].markAsDirty();
      this.salesmanForm.controls[i].updateValueAndValidity();
    }
    if (this.salesmanForm.status == null || this.salesmanForm.status !== 'VALID') {
      this.modal.warning({
        nzTitle: '提示',
        nzContent: '请规范填写所有的必填项信息',
      });
      return;
    }

    this.salesmanService.insertSalesman(this.salesmanForm.value, data => {
      if (data['return_code'] === '000000') {
        this.modal.success({
          nzTitle: '提示',
          nzContent: '添加成功',
          nzOnOk: () => this.router.navigateByUrl('admin/salesman/list')
        });
      } else {
        this.modal.error({
          nzTitle: '提示',
          nzContent: data['return_msg'],
        });
      }
      this.btnLoading = false;
    });
  }
}
