import { Component, OnInit } from '@angular/core';
import {StoreDeviceService} from '../../../services/store-device.service';
import {UntypedFormBuilder, UntypedFormGroup, Validators} from '@angular/forms';
import {ActivatedRoute} from '@angular/router';
import {NzMessageService, NzModalService} from 'ng-zorro-antd';
import {ADMIN_INFO_OBJECT} from '../../../services/local-storage.namespace';
import {LocalStorageService} from '../../../services/local-storage.service';

@Component({
  selector: 'app-store-device-list',
  templateUrl: './store-device-list.component.html',
  styleUrls: ['./store-device-list.component.scss']
})
export class StoreDeviceListComponent implements OnInit {
  dataObject: any = {};
  storeId: number;
  tableLoading = true;
  searchForm: UntypedFormGroup;
  pageNum: number;
  whereObject: any = {};

  addForm: UntypedFormGroup;
  addModal = false;

  constructor(private activatedRoute: ActivatedRoute,
              private store: LocalStorageService, // 数据请求
              private modal: NzModalService,
              private message: NzMessageService,
              private storeDeviceService: StoreDeviceService,
              private form: UntypedFormBuilder) { }

  ngOnInit(): void {
    this.activatedRoute.queryParams.subscribe(queryParams => {
      if (queryParams['storeId'] != null) {
        this.storeId = queryParams['storeId'];
      } else {
        this.storeId = this.store.get(ADMIN_INFO_OBJECT)['store']['id'];
      }
      this.requestData(1);
    });

    this.addForm = this.form.group({
      storeId: [null, [Validators.required]],
      deviceSn: [null, [Validators.required]],
    });
  }

  /**
   * 请求数据
   */
  requestData(pageNum) {
    this.tableLoading = true;
    this.whereObject['storeId'] = this.storeId;
    this.whereObject['pageNum'] = pageNum;
    this.whereObject['pageSize'] = 10;
    this.storeDeviceService.getStoreDeviceList(this.whereObject, data => {
      if (data['return_code'] === '000000') {
        this.dataObject = data['return_data'];
      } else {
        this.modal.error(data['return_msg']);
      }
      this.tableLoading = false;
    });
  }

  /**
   * 搜索
   * @param whereObject 条件
   */
  search(whereObject: object) {
    this.whereObject = whereObject;
    this.requestData(1);
  }

  /**
   * 重置
   */
  resetForm(): void {
    this.searchForm.reset();
  }

  /**
   * 打开增加设备模态框
   */
  showAddModal(): void {
    this.addForm.reset( { storeId: this.storeId});
    this.addModal = true;
  }

  /**
   * 关闭增加设备对话框
   */
  closeAddModal(): void {
    this.addModal = false;
  }

  /**
   * 弹出删除对话框
   */
  showDelConfirm(id: number): void {
    this.modal.confirm({
      nzTitle: '警告',
      nzContent: '是否删除门店设备？<br/>注意：如果设备正在使用，会导致设备无法使用',
      nzOkText: '是',
      nzCancelText: '否',
      nzOkType: 'danger',
      nzOnOk: () => this.delDevice(id)
    });
  }

  /**
   * 提交数据
   */
  submitAddData() {
    for (const i in this.addForm.controls) {
      this.addForm.controls[i].markAsDirty();
      this.addForm.controls[i].updateValueAndValidity();
    }
    if (this.addForm.status == null || this.addForm.status !== 'VALID') {
      this.modal.warning({
        nzTitle: '提示',
        nzContent: '请规范填写必填项信息',
      });
      return;
    }
    this.storeDeviceService.configStoreDevice(this.addForm.value, data => {
      if (data['return_code'] === '000000') {
        this.requestData(this.whereObject['pageNum']);
        this.closeAddModal();
      } else {
        this.modal.error({
          nzTitle: '提示',
          nzContent: data['return_msg']
        });
      }
    });
  }

  /**
   * 删除数据
   *
   */
  delDevice(id: number) {
    this.storeDeviceService.delStoreDevice({ id}, data => {
      if (data['return_code'] === '000000') {
        this.requestData(this.whereObject['pageNum']);
      } else {
        this.modal.error({
          nzTitle: '提示',
          nzContent: data['return_msg']
        });
      }
    });
  }
}
