import { Component, OnInit } from '@angular/core';
import {UntypedFormBuilder, UntypedFormGroup, Validators} from '@angular/forms';
import {ActivatedRoute} from '@angular/router';
import {LocalStorageService} from '../../../services/local-storage.service';
import {NzMessageService, NzModalService} from 'ng-zorro-antd';
import {StoreDiscountActivityService} from '../../../services/store-discount-activity.service';

@Component({
  selector: 'app-store-discount-activity-list',
  templateUrl: './store-discount-activity-list.component.html',
  styleUrls: ['./store-discount-activity-list.component.scss']
})
export class StoreDiscountActivityListComponent implements OnInit {
  dataObject: any = {};
  storeId: number;
  tableLoading = true;
  searchForm: UntypedFormGroup;
  pageNum: number;
  whereObject: any = {};

  BTN_STORE_DISCOUNT_ACTIVITY_ADD =  false;
  BTN_STORE_DISCOUNT_ACTIVITY_UPDATE =  false;
  BTN_STORE_DISCOUNT_ACTIVITY_DEL =  false;

  constructor(private activatedRoute: ActivatedRoute,
              private store: LocalStorageService, // 数据请求
              private modal: NzModalService,
              private message: NzMessageService,
              private storeDiscountActivityService: StoreDiscountActivityService,
              private form: UntypedFormBuilder) { }

  ngOnInit(): void {
    this.BTN_STORE_DISCOUNT_ACTIVITY_ADD = this.store.isBtnCompetence('BTN_STORE_DISCOUNT_ACTIVITY_ADD');  // 增加按钮权限
    this.BTN_STORE_DISCOUNT_ACTIVITY_UPDATE = this.store.isBtnCompetence('BTN_STORE_DISCOUNT_ACTIVITY_UPDATE');  // 修改按钮权限
    this.BTN_STORE_DISCOUNT_ACTIVITY_DEL = this.store.isBtnCompetence('BTN_STORE_DISCOUNT_ACTIVITY_DEL');  // 删除按钮权限


    this.searchForm = this.form.group({
      name: [null],
      status: [null],
    });
    this.requestData(1);
  }

  /**
   * 请求数据
   */
  requestData(pageNum) {
    this.tableLoading = true;
    this.whereObject['storeId'] = this.storeId;
    this.whereObject['pageNum'] = pageNum;
    this.whereObject['pageSize'] = 10;
    this.storeDiscountActivityService.getActivityList(this.whereObject, data => {
      if (data['return_code'] === '000000') {
        this.dataObject = data['return_data'];
      } else {
        this.modal.error(data['return_msg']);
      }
      this.tableLoading = false;
    });
  }

  /**
   * 搜索
   * @param whereObject 条件
   */
  search(whereObject: object) {
    this.whereObject = whereObject;
    this.requestData(1);
  }

  /**
   * 重置
   */
  resetForm(): void {
    this.searchForm.reset();
  }

  /**
   * 弹出上线对话框
   */
  showUpOnlineConfirm(id: number): void {
    this.modal.confirm({
      nzTitle: '警告',
      nzContent: '是否删除优惠活动？<br/>',
      nzOkText: '是',
      nzCancelText: '否',
      nzOkType: 'danger',
      nzOnOk: () => this.upOnline(id)
    });
  }

  /**
   * 活动上线数据
   *
   */
  upOnline(id: number) {
    this.storeDiscountActivityService.upOnline(id, data => {
      if (data['return_code'] === '000000') {
        this.requestData(this.whereObject['pageNum']);
      } else {
        this.modal.error({
          nzTitle: '提示',
          nzContent: data['return_msg']
        });
      }
    });
  }

  /**
   * 弹出活动下线对话框
   */
  showLowerOnlineConfirm(id: number): void {
    this.modal.confirm({
      nzTitle: '警告',
      nzContent: '是否删除优惠活动？<br/>',
      nzOkText: '是',
      nzCancelText: '否',
      nzOkType: 'danger',
      nzOnOk: () => this.lowerOnline(id)
    });
  }

  /**
   * 活动下线数据
   *
   */
  lowerOnline(id: number) {
    this.storeDiscountActivityService.lowerOnline(id, data => {
      if (data['return_code'] === '000000') {
        this.requestData(this.whereObject['pageNum']);
      } else {
        this.modal.error({
          nzTitle: '提示',
          nzContent: data['return_msg']
        });
      }
    });
  }

  /**
   * 弹出删除对话框
   */
  showDelConfirm(id: number): void {
    this.modal.confirm({
      nzTitle: '警告',
      nzContent: '是否删除优惠活动？<br/>',
      nzOkText: '是',
      nzCancelText: '否',
      nzOkType: 'danger',
      nzOnOk: () => this.delete(id)
    });
  }

  /**
   * 删除数据
   *
   */
  delete(id: number) {
    this.storeDiscountActivityService.delete(id, data => {
      if (data['return_code'] === '000000') {
        this.requestData(this.whereObject['pageNum']);
      } else {
        this.modal.error({
          nzTitle: '提示',
          nzContent: data['return_msg']
        });
      }
    });
  }
}
