import { Component, OnInit } from '@angular/core';
import {UntypedFormBuilder, UntypedFormGroup} from '@angular/forms';
import {NzMessageService, NzModalService} from 'ng-zorro-antd';
import {PlatformService} from '../../../services/platform.service';
import {TradeCheckingService} from '../../../services/trade-checking.service';
import {MerService} from '../../../services/mer.service';
import differenceInCalendarDays from 'date-fns/differenceInCalendarDays';
import {environment} from '../../../../environments/environment';
import {ADMIN_INFO_OBJECT} from '../../../services/local-storage.namespace';
import {LocalStorageService} from '../../../services/local-storage.service';
@Component({
  selector: 'app-trade-checking',
  templateUrl: './trade-checking.component.html',
  styleUrls: ['./trade-checking.component.scss']
})
export class TradeCheckingComponent implements OnInit {
  tableLoading = true;
  searchForm: UntypedFormGroup;
  pageNum: number;
  whereObject: any = {};
  loadingObject = {
    spinning: false,
    msg: '处理中'
  };
  merArray = [];
  dataObject = {
    totalTradeNum: 0,
    totalTradeAmount: 0,
    totalSettleAmount: 0,
    totalShdFeeAmount: 0,
    settleList: []
  };
  currentDate = new Date();
  // 角色类型 0：超级管理员  1：公司  2：代理商  3：业务员  4：商户  5：门店
  roleType: number;
  constructor(private modal: NzModalService,
              private message: NzMessageService,
              private form: UntypedFormBuilder,
              private platformService: PlatformService,
              private localStorage: LocalStorageService,
              private merService: MerService,
              private tradeCheckingService: TradeCheckingService) {
  }

  ngOnInit(): void {
    this.roleType = this.localStorage.get(ADMIN_INFO_OBJECT)['secRole'].roleType;

    this.currentDate.setDate(this.currentDate.getDate() - 1);
    this.searchForm = this.form.group({
      merNo: [null],
      settleTimeS: [ this.currentDate.getTime() ],
      settleTimeE: [ this.currentDate.getTime() ],
    });

    if (this.roleType == 2) {
      this.merService.getMerList({ merStatus: 1, pageNum: 1, pageSize: 9999}, data => {
        this.merArray = data['return_data']['list'];
        if (this.merArray.length > 0) {
          this.searchForm.controls['merNo'].setValue(this.merArray[0]['merNo']);
          this.requestData();
        }
      });
    } else if (this.roleType == 4) {
      this.merArray.push(this.localStorage.get(ADMIN_INFO_OBJECT)['mer']);
      this.searchForm.controls['merNo'].setValue(this.merArray[0]['merNo']);
      this.requestData();
    }
  }

  /**
   * 请求数据
   */
  requestData() {
    this.tableLoading = true;
    this.tradeCheckingService.queryChecking(this.searchForm.value, data => {
      if (data['return_code'] === '000000') {
        this.dataObject = data['return_data'];
      } else {
        this.modal.error({
          nzTitle: '提示',
          nzContent: data['return_msg']
        });
      }
      this.tableLoading = false;
    });
  }

  /**
   * 搜索
   * @param whereObject 条件
   */
  search(whereObject: object) {
    whereObject['settleTimeS'] = new Date(whereObject['settleTimeS']).getTime();
    whereObject['settleTimeE'] = new Date(whereObject['settleTimeE']).getTime();
    this.whereObject = whereObject;
    this.requestData();
  }

  /**
   * 重置
   */
  resetForm(): void {
    this.searchForm.reset();
    this.searchForm.controls['merNo'].setValue(this.merArray.length > 0 ? this.merArray[0]['merNo'] : null);
    this.searchForm.controls['settleTimeS'].setValue(this.currentDate.getTime());
    this.searchForm.controls['settleTimeE'].setValue(this.currentDate.getTime());
  }


  disabledDate = (current: Date): boolean => {
    // Can not select days before today and today
   return differenceInCalendarDays(current, new Date()) > 0;
  };


  searchSettleTime(dateType: number, selectDate: Date) {
    const currentDate = new Date();
    if (currentDate.getFullYear() === selectDate.getFullYear()
        && currentDate.getMonth() === selectDate.getMonth()
        && currentDate.getDate() === selectDate.getDate()) {
      this.modal.error({
        nzTitle: '提示',
        nzContent: '无法选择当日，当日还未清算'
      });
      return;
      // 起始时间
      if (dateType === 1) {
        this.searchForm.controls['settleTimeS'].setValue(this.currentDate.getTime());
        // 终止时间
      } else if (dateType === 2) {
        this.searchForm.controls['settleTimeE'].setValue(this.currentDate.getTime());
      }
    }
  }

  download() {
    this.loadingObject.spinning = true;
    this.loadingObject.msg = '处理中...';
    this.tradeCheckingService.exportChecking(this.searchForm.value, data => {
      if (data['return_code'] === '000000') {
        window.location.href = environment.imageUrl + data['return_data'];
      } else {
        this.modal.error({
          nzTitle: '提示',
          nzContent: data['return_msg']
        });
      }
      this.loadingObject.spinning = false;
    });
  }

  showPrint() {
    console.log(document.getElementById('print-content').innerHTML);
    const oblHtml = window.document.body.innerHTML;
    const bdhtml = document.getElementById('print-content').innerHTML;
    window.document.body.innerHTML = bdhtml;
    window.print();
    document.body.innerHTML = oblHtml;
    window.location.reload();
  }

}
