import { Component, OnInit } from '@angular/core';
import {TradeOrderService} from '../../../services/trade-order.service';
import {LocalStorageService} from '../../../services/local-storage.service';
import {ADMIN_INFO_OBJECT} from '../../../services/local-storage.namespace';
import {StoreService} from '../../../services/store.service';
import {UntypedFormBuilder, UntypedFormGroup} from '@angular/forms';
import {NzMessageService, NzModalService} from 'ng-zorro-antd';
import {environment} from '../../../../environments/environment';

@Component({
  selector: 'app-trade-order-list',
  templateUrl: './trade-order-list.component.html',
  styleUrls: ['./trade-order-list.component.scss']
})
export class TradeOrderListComponent implements OnInit {
  FILE_URL = environment.imageUrl;
  loading = false;
  dataObject: any = {};
  tableLoading = true;
  searchForm: UntypedFormGroup;
  pageNum: number;
  whereObject: any = {};
  userObjectType: number;
  storeArray = [];

  loadingObject = {
    spinning: false,
    msg: '加载中'
  };

  isCollapse = false;

  constructor(private store: LocalStorageService, // 数据请求
              private modal: NzModalService,
              private message: NzMessageService,
              private tradeOrderService: TradeOrderService,
              private storeService: StoreService,
              private form: UntypedFormBuilder) { }

  ngOnInit(): void {
    this.userObjectType = this.store.get(ADMIN_INFO_OBJECT)['secUser']['objectType'];
    // 用户来源 0：超级管理员  1：公司  2：代理商  3：业务员  4：商户  5：门店
    if (this.userObjectType === 4) {
      // 查询门店
      this.storeService.getStoreListByMer({ merId: this.store.get(ADMIN_INFO_OBJECT)['mer']['id'], pageNum : 1, pageSize: 99999}, data => {
          this.storeArray = data['return_data']['list'];
      });
    }

    this.searchForm = this.form.group({
      salesmanId: [null],
      merNo: [null],
      merId: [null],
      merName: [null],
      merAbbreviate: [null],
      storeName: [null],
      outTradeNo: [null],
      accTradeNo: [null],
      payMode: [null],
      payTime: [null],
      payTimeS: [null],
      payTimeE: [null],
      status: [null],
      specialField: [null],
    });
    this.requestData(1);
  }

  /**
   * 请求数据
   */
  requestData(pageNum) {
    this.tableLoading = true;
    this.whereObject['pageNum'] = pageNum;
    this.whereObject['pageSize'] = 10;
    this.tradeOrderService.getOrderList(this.whereObject, data => {
      if (data['return_code'] === '000000') {
        this.dataObject = data['return_data'];
      } else {
        this.modal.error(data['return_msg']);
      }
      this.tableLoading = false;
    });
  }

  /**
   * 搜索
   * @param whereObject 条件
   */
  search(whereObject: object) {
    if (whereObject['payTime'] != null) {
      whereObject['payTimeS'] = new Date(whereObject['payTime'][0]).getTime();
      whereObject['payTimeE'] = new Date(whereObject['payTime'][1]).getTime();
    }
    this.whereObject = whereObject;
    this.requestData(1);
  }

  /**
   * 重置
   */
  resetForm(): void {
    this.searchForm.reset();
  }

  /**
   * 弹出退款对话框
   */
  showOrderRefundConfirm(outTradeNo: string, refundAmount: string): void {
    this.modal.confirm({
      nzTitle: '警告',
      nzContent: '确定退款吗？',
      nzOkText: '是',
      nzCancelText: '否',
      nzOkType: 'danger',
      nzOnOk: () => this.requestOrderRefund(outTradeNo, refundAmount)
    });
  }

  /**
   * 删除数据
   *
   */
  requestOrderRefund(outTradeNo: string, refundAmount: string) {
    this.loading = true;
    this.tradeOrderService.refund({ outTradeNo, refundAmount}, data => {
      if (data['return_code'] === '000000') {
        this.modal.success({
          nzTitle: '提示',
          nzContent: '处理成功',
          nzOnOk: () => this.requestData(this.whereObject['pageNum'])
        });
      } else {
        this.modal.error({
          nzTitle: '提示',
          nzContent: data['return_msg']
        });
      }
      this.loading = false;
    });
  }

  exportTradeOrder() {
    this.loadingObject.spinning = true;
    this.loadingObject.msg = '导出中...';
    this.tradeOrderService.exportTradeOrder(this.whereObject, data => {
      if (data['return_code'] === '000000') {
        window.location.href = this.FILE_URL + data['return_data'];
      } else {
        this.message.error(data['return_msg']);
      }
      this.loadingObject.spinning = false;
    });
  }

  toggleCollapse(): void {
    this.isCollapse = !this.isCollapse;
  }

}
